add timezone support to time match
diff --git a/extensions/libipt_time.c b/extensions/libipt_time.c
index 8fde010..1ad5058 100644
--- a/extensions/libipt_time.c
+++ b/extensions/libipt_time.c
@@ -221,13 +221,13 @@
 	return 1;
 }
 
 /* Final check; must have specified --time-start --time-stop --days. */
 static void
 final_check(unsigned int flags)
 {
 	if (flags != (IPT_TIME_START | IPT_TIME_STOP | IPT_TIME_DAYS))
 		exit_error(PARAMETER_PROBLEM,
-			   "TIME match: You must specify `--time-start --time-stop and --days'");
+			   "TIME match: You must specify `--timestart --timestop and --days'");
 }
@@ -221,13 +221,13 @@
 }
 
-/* Final check; must have specified --time-start --time-stop --days. */
+/* Final check; must have specified --timestart --timestop --days. */
 static void
 final_check(unsigned int flags)